@@ -164,7 +164,7 @@ describe 'keystone' do
       if param_hash['public_endpoint']
         is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value(param_hash['public_endpoint'])
       else
-        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')
+        is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -265,45 +265,6 @@ describe 'keystone' do
     ) }
   end
 
-  describe 'when public_bind_host or public_bind_port are set' do
-    describe 'when ipv6 loopback is set' do
-      let :params do
-        {
-          :public_bind_host => '::0'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[::1]:5000') }
-    end
-
-    describe 'when ipv4 address is set' do
-      let :params do
-        {
-          :public_bind_host => '192.168.0.1',
-          :public_port      => '15000'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://192.168.0.1:15000') }
-    end
-
-    describe 'when unenclosed ipv6 address is set' do
-      let :params do
-        {
-          :public_bind_host => '2001:db8::1'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
-    end
-
-    describe 'when enclosed ipv6 address is set' do
-      let :params do
-        {
-          :public_bind_host => '[2001:db8::1]'
-        }
-      end
-      it { is_expected.to contain_keystone_config("DEFAULT/public_endpoint").with_value('http://[2001:db8::1]:5000') }
-    end
-  end
-
   describe 'when using invalid service name for keystone' do
     let (:params) { {'service_name' => 'foo'}.merge(default_params) }
 
@@ -380,133 +341,10 @@ describe 'keystone' do
     it { is_expected.not_to contain_exec('keystone-manage db_sync') }
   end
 
-  describe 'configure memcache servers if set' do
-    let :params do
-      {
-        'cache_backend'                => 'dogpile.cache.memcached',
-        'cache_backend_argument'       => ['url:SERVER1:12211'],
-        'cache_memcache_servers'       => 'SERVER1:11211,SERVER2:11211,[fd12:3456:789a:1::1]:11211',
-        'memcache_dead_retry'          => '60',
-        'memcache_socket_timeout'      => '2.0',
-        'memcache_pool_maxsize'        => '1000',
-        'memcache_pool_unused_timeout' => '60',
-      }
-    end
-
-    it { is_expected.to contain_keystone_config('cache/enabled').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
-    it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER1:12211') }
-    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2.0') }
-    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2.0') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
-  end
-
-  describe 'configure cache memcache servers if set' do
-    let :params do
-      {
-        'cache_backend'                        => 'dogpile.cache.memcached',
-        'cache_backend_argument'               => ['url:SERVER3:12211'],
-        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211', '[fd12:3456:789a:1::1]:11211' ],
-        'memcache_dead_retry'                  => '60',
-        'memcache_socket_timeout'              => '2.0',
-        'memcache_pool_maxsize'                => '1000',
-        'memcache_pool_unused_timeout'         => '60',
-        'memcache_pool_connection_get_timeout' => '30',
-        'manage_backend_package'               => false,
-      }
-    end
-
-    it { is_expected.to contain_keystone_config('cache/enabled').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
-    it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
-    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2.0') }
-    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2.0') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
-    it { is_expected.to contain_oslo__cache('keystone_config').with_manage_backend_package(false) }
-  end
-
-  describe 'configure cache enabled if set' do
-    let :params do
-      {
-        'cache_backend'                        => 'dogpile.cache.memcached',
-        'cache_backend_argument'               => ['url:SERVER3:12211'],
-        'cache_enabled'                        => true,
-        'cache_memcache_servers'               => [ 'SERVER1:11211', 'SERVER2:11211', '[fd12:3456:789a:1::1]:11211' ],
-        'memcache_dead_retry'                  => '60',
-        'memcache_socket_timeout'              => '2.0',
-        'memcache_pool_maxsize'                => '1000',
-        'memcache_pool_unused_timeout'         => '60',
-        'memcache_pool_connection_get_timeout' => '30',
-      }
-    end
-
-    it { is_expected.to contain_keystone_config('cache/enabled').with_value(true) }
-    it { is_expected.to contain_keystone_config('token/caching').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcached') }
-    it { is_expected.to contain_keystone_config('cache/backend_argument').with_value('url:SERVER3:12211') }
-    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('memcache/socket_timeout').with_value('2.0') }
-    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('2.0') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('1000') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('30') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
-  end
-
-  describe 'configure memcache servers with a string' do
-    let :params do
-      default_params.merge({
-        'cache_memcache_servers' => 'SERVER1:11211,SERVER2:11211,[fd12:3456:789a:1::1]:11211'
-      })
-    end
-
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('SERVER1:11211,SERVER2:11211,inet6:[fd12:3456:789a:1::1]:11211') }
-  end
-
-  describe 'do not configure memcache servers when not set' do
-    let :params do
-      default_params
-    end
-
-    it { is_expected.to contain_keystone_config("cache/enabled").with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config("token/caching").with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config("cache/backend").with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config("cache/backend_argument").with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config("cache/debug_cache_backend").with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('memcache/dead_retry').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('memcache/pool_maxsize').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('memcache/pool_unused_timeout').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_keystone_config('cache/memcache_servers').with_value('<SERVICE DEFAULT>') }
-  end
-
   describe 'when enabling SSL' do
     let :params do
       {
         'enable_ssl'      => true,
-        'public_endpoint' => 'https://localhost:5000',
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(true)}
@@ -515,7 +353,6 @@ describe 'keystone' do
     it {is_expected.to contain_keystone_config('ssl/ca_certs').with_value('/etc/keystone/ssl/certs/ca.pem')}
     it {is_expected.to contain_keystone_config('ssl/ca_key').with_value('/etc/keystone/ssl/private/cakey.pem')}
     it {is_expected.to contain_keystone_config('ssl/cert_subject').with_value('/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost')}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('https://localhost:5000')}
   end
 
   describe 'when disabling SSL' do
@@ -525,7 +362,6 @@ describe 'keystone' do
       }
     end
     it {is_expected.to contain_keystone_config('ssl/enable').with_value(false)}
-    it {is_expected.to contain_keystone_config('DEFAULT/public_endpoint').with_value('http://127.0.0.1:5000')}
   end
 
   describe 'not setting notification settings by default' do
@@ -600,7 +436,7 @@ describe 'keystone' do
       })
     end
 
-    it { is_expected.to contain_keystone_config('oslo_messaging_notifications/driver').with_value('keystone.openstack.common.notifier.rpc_notifier') }
+    it { is_expected.to contain_keystone_config('oslo_messaging_notifications/driver').with_value(['keystone.openstack.common.notifier.rpc_notifier']) }
     it { is_expected.to contain_keystone_config('oslo_messaging_notifications/topics').with_value('notifications') }
     it { is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('cadf') }
     it { is_expected.to contain_keystone_config('DEFAULT/control_exchange').with_value('keystone') }
